@@ -25,6 +25,7 @@ static float floatQualifier = 23.123f;
 static const char c1 = 'c';
 static const char c2 = '\n';
 static const char c2a = '\120'; // octal
+static const char c2o = '\0'; // octal, special case
 static const char c2b = '\x1f'; // hex
 static const char c2c = '\'';
 static const char c2d = '\\';
@@ -54,3 +55,43 @@ static const char* c5 = "multiline \
  */
 
 #endif
+
+/*
+ * Empty lines after a line continuation character (see bug #405903)
+ */
+#define one \
+two \
+
+int i = 0; // this should not be highlighted as a macro
+char* str = "string \
+
+
+int i = 0; // this should not be highlighted as a string
+
+/*
+ * Digraphs (see bug #411508)
+ */
+%:include <stdio.h>
+int a()
+<%
+    [](){%>();
+}
+
+#define 1
+ #define 2
+  #define 3
+   #define 4
+    #define 5
+	#define tab
+
+#if 1
+int x; // variable shall not be grey
+#endif
+#if defined (A)
+int y; // variable shall not be grey
+#elif defined (B)
+int z; // variable shall not be grey
+#endif
+
+// C23 format
+"%w8ux %w8dx %DDfx";
